@@ -16,6 +16,7 @@
 #include <KConfigPropertyMap>
 #include <KDesktopFile>
 #include <KLocalizedString>
+#include <KPackage/PackageJob>
 #include <KPackage/PackageLoader>
 #include <KPluginMetaData>
 #include <Solid/Block>
@@ -36,11 +37,7 @@ void FacesModel::reload()
 {
     clear();
 
-    auto list = KPackage::PackageLoader::self()->listPackages(QStringLiteral("KSysguard/SensorFace"));
-    // NOTE: This will disable completely the internal in-memory cache
-    KPackage::Package p;
-    p.install(QString(), QString());
-
+    const auto list = KPackage::PackageLoader::self()->listPackages(QStringLiteral("KSysguard/SensorFace"));
     for (auto plugin : list) {
         QStandardItem *item = new QStandardItem(plugin.name());
         item->setData(plugin.pluginId(), FacesModel::PluginIdRole);
@@ -110,7 +107,7 @@ void PresetsModel::reload()
         item->setData(plugin.pluginId(), PresetsModel::PluginIdRole);
         item->setData(config, PresetsModel::ConfigRole);
 
-        item->setData(QFileInfo(p.metadata().metaDataFileName()).isWritable(), PresetsModel::WritableRole);
+        item->setData(QFileInfo(p.metadata().fileName()).isWritable(), PresetsModel::WritableRole);
 
         appendRow(item);
     }
@@ -159,7 +156,7 @@ void SensorResolver::execute()
     });
 }
 
-QVector<QPair<QRegularExpression, QString>> KSysGuard::SensorFaceControllerPrivate::sensorIdReplacements;
+QList<QPair<QRegularExpression, QString>> KSysGuard::SensorFaceControllerPrivate::sensorIdReplacements;
 QRegularExpression SensorFaceControllerPrivate::oldDiskSensor = QRegularExpression(QStringLiteral("^disk\\/(.+)_\\(\\d+:\\d+\\)"));
 QRegularExpression SensorFaceControllerPrivate::oldPartitionSensor = QRegularExpression(QStringLiteral("^partitions(\\/.+)\\/"));
 
@@ -401,6 +398,10 @@ SensorFaceController::SensorFaceController(KConfigGroup &config, QQmlEngine *eng
 
 SensorFaceController::~SensorFaceController()
 {
+    if (!d->faceProperties.isValid()) {
+        return;
+    }
+
     auto forceSave = d->faceProperties.readEntry(QStringLiteral("ForceSaveOnDestroy"), false);
     if (!forceSave) {
         if (!d->shouldSync) {
@@ -643,21 +644,37 @@ const QString SensorFaceController::icon() const
 
 bool SensorFaceController::supportsSensorsColors() const
 {
+    if (!d->faceProperties.isValid()) {
+        return false;
+    }
+
     return d->faceProperties.readEntry("SupportsSensorsColors", false);
 }
 
 bool SensorFaceController::supportsTotalSensors() const
 {
+    if (!d->faceProperties.isValid()) {
+        return false;
+    }
+
     return d->faceProperties.readEntry("SupportsTotalSensors", false);
 }
 
 bool SensorFaceController::supportsLowPrioritySensors() const
 {
+    if (!d->faceProperties.isValid()) {
+        return false;
+    }
+
     return d->faceProperties.readEntry("SupportsLowPrioritySensors", false);
 }
 
 int SensorFaceController::maxTotalSensors() const
 {
+    if (!d->faceProperties.isValid()) {
+        return 1;
+    }
+
     return d->faceProperties.readEntry("MaxTotalSensors", 1);
 }
 
@@ -702,6 +719,11 @@ void SensorFaceController::setFaceId(const QString &face)
 
     d->faceProperties = KConfigGroup(KSharedConfig::openConfig(d->facePackage.filePath("FaceProperties"), KConfig::SimpleConfig), QStringLiteral("Config"));
 
+    if (!d->faceProperties.isValid()) {
+        Q_EMIT faceIdChanged();
+        return;
+    }
+
     reloadFaceConfiguration();
 
     d->appearanceGroup.writeEntry("chartFace", face);
@@ -759,7 +781,7 @@ QQuickItem *SensorFaceController::faceConfigUi()
     }
 
     d->faceConfigUi = d->createConfigUi(QStringLiteral(":/FaceDetailsConfig.qml"),
-                                        {{QStringLiteral("controller"), QVariant::fromValue(this)}, {QStringLiteral("source"), filePath}});
+                                        {{QStringLiteral("controller"), QVariant::fromValue(this)}, {QStringLiteral("source"), QUrl::fromLocalFile(filePath)}});
 
     if (d->faceConfigUi && !d->faceConfigUi->property("item").value<QQuickItem *>()) {
         d->faceConfigUi->deleteLater();
@@ -785,7 +807,7 @@ QQuickItem *SensorFaceController::sensorsConfigUi()
         return d->sensorsConfigUi;
     }
 
-    if (d->faceProperties.readEntry("SupportsSensors", true)) {
+    if (d->faceProperties.isValid() && d->faceProperties.readEntry("SupportsSensors", true)) {
         d->sensorsConfigUi = d->createConfigUi(QStringLiteral(":/ConfigSensors.qml"), {{QStringLiteral("controller"), QVariant::fromValue(this)}});
     } else {
         d->sensorsConfigUi = new QQuickItem;
@@ -936,12 +958,12 @@ void SensorFaceController::savePreset()
              {"License", "LGPL 2.1+"},
              {"EnabledByDefault", true},
              {"Version", "0.1"},
-             {"ServiceTypes", QJsonArray{{"Plasma/Applet"}}} //
          }},
         {"X-Plasma-API", "declarativeappletscript"},
         {"X-Plasma-MainScript", "ui/main.qml"},
         {"X-Plasma-Provides", "org.kde.plasma.systemmonitor"},
         {"X-Plasma-RootPath", "org.kde.plasma.systemmonitor"},
+        {"KPackageStructure", "Plasma/Applet"},
     });
 
     if (QFile file{dir.path() % QStringLiteral("/metadata.json")}; file.open(QIODevice::WriteOnly)) {
@@ -950,25 +972,6 @@ void SensorFaceController::savePreset()
         qWarning() << "Could not write metadata.json file for preset" << title();
     }
 
-    // Backward compatibility: Also write out an "old style" desktop file so the
-    // preset works with older Plasma.
-    KConfig c(dir.path() % QStringLiteral("/metadata.desktop"));
-
-    KConfigGroup cg(&c, "Desktop Entry");
-    cg.writeEntry("Name", title());
-    cg.writeEntry("Icon", "ksysguardd");
-    cg.writeEntry("X-Plasma-API", "declarativeappletscript");
-    cg.writeEntry("X-Plasma-MainScript", "ui/main.qml");
-    cg.writeEntry("X-Plasma-Provides", "org.kde.plasma.systemmonitor");
-    cg.writeEntry("X-Plasma-RootPath", "org.kde.plasma.systemmonitor");
-    cg.writeEntry("X-KDE-PluginInfo-Name", pluginName);
-    cg.writeEntry("X-KDE-ServiceTypes", "Plasma/Applet");
-    cg.writeEntry("X-KDE-PluginInfo-Category", "System Information");
-    cg.writeEntry("X-KDE-PluginInfo-License", "LGPL 2.1+");
-    cg.writeEntry("X-KDE-PluginInfo-EnabledByDefault", "true");
-    cg.writeEntry("X-KDE-PluginInfo-Version", "0.1");
-    cg.sync();
-
     QDir subDir(dir.path());
     subDir.mkpath(QStringLiteral("contents/config"));
     KConfig faceConfig(subDir.path() % QStringLiteral("/contents/config/faceproperties"));
@@ -996,9 +999,8 @@ void SensorFaceController::savePreset()
     }
     configGroup.sync();
 
-    auto *job = presetPackage.install(dir.path());
-
-    connect(job, &KJob::finished, this, [this, pluginName]() {
+    auto *job = KPackage::PackageJob::install(QStringLiteral("Plasma/Applet"), dir.path());
+    connect(job, &KJob::finished, this, [this]() {
         d->availablePresetsModel->reload();
     });
 }
@@ -1013,7 +1015,7 @@ void SensorFaceController::uninstallPreset(const QString &pluginId)
 
     QDir root(presetPackage.path());
     root.cdUp();
-    auto *job = presetPackage.uninstall(pluginId, root.path());
+    auto *job = KPackage::PackageJob::uninstall(QStringLiteral("Plasma/Applet"), pluginId, root.path());
 
     connect(job, &KJob::finished, this, [this]() {
         d->availablePresetsModel->reload();
